Documentation
¶
Index ¶
- func APIIndexHandler(c echo.Context) error
- func IndexHandler(c echo.Context) error
- func LogoutHandler(c echo.Context) error
- func NewAPIAccountListHandler(s models.AccountStore) echo.HandlerFunc
- func NewAPIConsoleRedirectHandler(a *AWSAPI, fe string) echo.HandlerFunc
- func NewAPICredentialsHandler(a *AWSAPI) echo.HandlerFunc
- func NewAPIRegionListHandler(a *AWSAPI) echo.HandlerFunc
- func NewAPIUserListHandler(s models.UserStore) echo.HandlerFunc
- type APIAccountHandler
- func (h *APIAccountHandler) HandleDelete(c echo.Context) error
- func (h *APIAccountHandler) HandleGet(c echo.Context) error
- func (h *APIAccountHandler) HandlePost(c echo.Context) error
- func (h *APIAccountHandler) HandlePut(c echo.Context) error
- func (h *APIAccountHandler) Register(prefix, postPrefix string, r glecho.URLRouter, mw ...echo.MiddlewareFunc)
- type APIAccountListHandler
- type APIConsoleRedirectHandler
- type APICredentialsHandler
- type APIRegionListHandler
- type APIUserHandler
- func (h *APIUserHandler) HandleDelete(c echo.Context) error
- func (h *APIUserHandler) HandleGet(c echo.Context) error
- func (h *APIUserHandler) HandlePost(c echo.Context) error
- func (h *APIUserHandler) HandlePut(c echo.Context) error
- func (h *APIUserHandler) Register(prefix, postPrefix string, r glecho.URLRouter, mw ...echo.MiddlewareFunc)
- type APIUserListHandler
- type AWSAPI
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func APIIndexHandler ¶
func IndexHandler ¶
func LogoutHandler ¶
func NewAPIAccountListHandler ¶
func NewAPIAccountListHandler(s models.AccountStore) echo.HandlerFunc
func NewAPIConsoleRedirectHandler ¶
func NewAPIConsoleRedirectHandler(a *AWSAPI, fe string) echo.HandlerFunc
func NewAPICredentialsHandler ¶
func NewAPICredentialsHandler(a *AWSAPI) echo.HandlerFunc
func NewAPIRegionListHandler ¶
func NewAPIRegionListHandler(a *AWSAPI) echo.HandlerFunc
func NewAPIUserListHandler ¶
func NewAPIUserListHandler(s models.UserStore) echo.HandlerFunc
Types ¶
type APIAccountHandler ¶
type APIAccountHandler struct {
Store models.AccountStore
AdminStore models.AccountStore
}
func (*APIAccountHandler) HandleDelete ¶
func (h *APIAccountHandler) HandleDelete(c echo.Context) error
func (*APIAccountHandler) HandlePost ¶
func (h *APIAccountHandler) HandlePost(c echo.Context) error
func (*APIAccountHandler) Register ¶
func (h *APIAccountHandler) Register(prefix, postPrefix string, r glecho.URLRouter, mw ...echo.MiddlewareFunc)
type APIAccountListHandler ¶
type APIAccountListHandler struct {
// contains filtered or unexported fields
}
type APICredentialsHandler ¶
type APICredentialsHandler struct {
*AWSAPI
}
func (*APICredentialsHandler) HandleBashV2 ¶
func (h *APICredentialsHandler) HandleBashV2(c echo.Context) error
func (*APICredentialsHandler) HandleINIV2 ¶
func (h *APICredentialsHandler) HandleINIV2(c echo.Context) error
func (*APICredentialsHandler) HandleJSONV1 ¶
func (h *APICredentialsHandler) HandleJSONV1(c echo.Context) error
func (*APICredentialsHandler) HandlePSLV2 ¶
func (h *APICredentialsHandler) HandlePSLV2(c echo.Context) error
type APIRegionListHandler ¶
type APIRegionListHandler struct {
*AWSAPI
// contains filtered or unexported fields
}
type APIUserHandler ¶
func (*APIUserHandler) HandleDelete ¶
func (h *APIUserHandler) HandleDelete(c echo.Context) error
func (*APIUserHandler) HandlePost ¶
func (h *APIUserHandler) HandlePost(c echo.Context) error
func (*APIUserHandler) Register ¶
func (h *APIUserHandler) Register(prefix, postPrefix string, r glecho.URLRouter, mw ...echo.MiddlewareFunc)
type APIUserListHandler ¶
type APIUserListHandler struct {
// contains filtered or unexported fields
}
type AWSAPI ¶
type AWSAPI struct {
Store models.AccountStore
Secrets secrets.Client
// contains filtered or unexported fields
}
AWSAPI is a capability that all handlers talking to the AWS APIs should use. This capability does common permission checks and populates a request context with user, account, and AWS API information.
func (*AWSAPI) GetContext ¶
GetContext checks that the user is authenticated and is authorized to access the requested AWS account. This should be the very first call in any handler that will eventually call the AWS APIs. Errors returned from this method are echo responses and can be returned directly to the client.
Click to show internal directories.
Click to hide internal directories.